package MFString;
use strict;
use warnings;

use rlib "./";

use MFScalar;
use base qw(MFScalar);

use SFString;
our $SField = new SFString;

1;
__END__
